@@ -2,11 +2,10 @@
 # -*- coding: utf-8 -*-
 
 import six
-from bson.objectid import ObjectId
+from tornado.concurrent import return_future
 
 from motorengine.metaclasses import DocumentMetaClass
 from motorengine.errors import InvalidDocumentError, LoadReferencesRequiredError
-from motorengine.utils import get_class
 
 
 AUTHORIZED_FIELDS = ['_id', '_values']
@@ -18,7 +17,10 @@ class BaseDocument(object):
         self._values = {}
 
         for key, field in self._fields.items():
-            self._values[key] = field.default
+            if callable(field.default):
+                self._values[key] = field.default()
+            else:
+                self._values[key] = field.default
 
         for key, value in kw.items():
             if key not in self._db_field_map:
@@ -65,6 +67,7 @@ class BaseDocument(object):
 
         return True
 
+    @return_future
     def save(self, callback, alias=None):
         '''
         Saves a new instance of this document.
@@ -82,14 +85,18 @@ class BaseDocument(object):
 
     def handle_load_reference(self, callback, references, reference_count, values_collection, field_name):
         def handle(*args, **kw):
-            values_collection[field_name] = kw['instance']
+            values_collection[field_name] = args[0]
             references.pop()
 
             if len(references) == 0:
-                callback(result=reference_count)
+                callback({
+                    'loaded_reference_count': reference_count,
+                    'loaded_values': values_collection
+                })
 
         return handle
 
+    @return_future
     def load_references(self, callback, alias=None):
         references = self.find_references(self)
         reference_count = len(references)
@@ -107,27 +114,34 @@ class BaseDocument(object):
 
     def find_references(self, document, results=[]):
         for field_name, field in document._fields.items():
-            if self.is_reference_field(field):
-                value = document._values.get(field_name, None)
-                if value is not None:
-                    results.append([
-                        field._reference_document_type.objects.get,
-                        value,
-                        document._values,
-                        field_name
-                    ])
+            self.find_reference_field(document, results, field_name, field)
+            self.find_list_field(document, results, field_name, field)
+            self.find_embed_field(document, results, field_name, field)
 
-            if self.is_list_field(field):
-                for value in document._values[field_name]:
-                    if value:
-                        self.find_references(value, results)
+        return results
 
-            if self.is_embedded_field(field):
-                value = document._values.get(field_name, None)
+    def find_reference_field(self, document, results, field_name, field):
+        if self.is_reference_field(field):
+            value = document._values.get(field_name, None)
+            if value is not None:
+                results.append([
+                    field._reference_document_type.objects.get,
+                    value,
+                    document._values,
+                    field_name
+                ])
+
+    def find_list_field(self, document, results, field_name, field):
+        if self.is_list_field(field):
+            for value in document._values[field_name]:
                 if value:
                     self.find_references(value, results)
 
-        return results
+    def find_embed_field(self, document, results, field_name, field):
+        if self.is_embedded_field(field):
+            value = document._values.get(field_name, None)
+            if value:
+                self.find_references(value, results)
 
     def __getattribute__(self, name):
         # required for the next test
@@ -139,7 +153,12 @@ class BaseDocument(object):
             value = self._values.get(name, None)
 
             if is_reference_field and not isinstance(value, self._fields[name]._reference_document_type):
-                raise LoadReferencesRequiredError("The property '%s' can't be accessed before calling 'load_references' on its instance first (%s) or setting __lazy__ to False in the %s class." % (name, self.__class__.__name__, self.__class__.__name__))
+                message = "The property '%s' can't be accessed before calling 'load_references'" + \
+                    " on its instance first (%s) or setting __lazy__ to False in the %s class."
+
+                raise LoadReferencesRequiredError(
+                    message % (name, self.__class__.__name__, self.__class__.__name__)
+                )
 
             return value
 
